cc876: Migrate Technology Ltd demo data

cc876R Documentation

Migrate Technology Ltd demo data

Description

Demo data for a single day of Common swift light logger data as read from a Migrate Technology Ltd .lux file using stk_read_lux().

Usage

cc876

Format

DataFrame

logger

logger ID

date

date

date_time

date and time

hour

decimal hour

lux

light levels in lux

Details

The format is consistent with what is required by the skytrackr() routine.


skytrackr documentation built on Nov. 5, 2025, 6:47 p.m.