| likelihood | R Documentation |
Main cost function used during optimization, combining both the fit of the illuminance data with the step-selection function.
likelihood(par, data, model, loc, roi, step_selection, ...)
par |
A vector of parameter values, including one for the uncertainty on the target values. |
data |
A nested data structure with validation data included. |
model |
A model to run with data and par settings. |
loc |
The previous modeled step location. |
roi |
A region of interest with valid sampling locations. |
step_selection |
A step selection function on the distance of a proposed move. |
... |
extra arguments to pass to the function |
The single log-likelihood cost of a proposed parameter set.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.