| log_lux | R Documentation |
Calculates log(lux) values for a give location, date, time and sky conditions.
log_lux(par, data, ...)
par |
Three parameters specifying the illuminance model. |
data |
A data frame with the required drivers for the illuminance model. |
... |
optional other parameters to forward |
Sky illuminance as log(lux).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.