stk_profile: Plot seasonal profiles

View source: R/stk_profile.R

stk_profileR Documentation

Plot seasonal profiles

Description

Provides static or dynamic (plotly) seasonal profile plot

Usage

stk_profile(data, logger, range = c(0, 1e+05), center = "day", plotly = FALSE)

Arguments

data

A skytrackr compatible data frame.

logger

The logger to plot.

range

The light range to plot.

center

Set the data to center data on "day" or "night" (default = "day").

plotly

Logical, convert to dynamic plotly plot or not (default = FALSE)

Value

A static or dynamic graph of light levels for a given logger.


skytrackr documentation built on Nov. 5, 2025, 6:47 p.m.