| cc876 | R Documentation |
Demo data for a single day of Common swift light logger data as read from a Migrate Technology Ltd .lux file using stk_read_lux().
cc876
DataFrame
logger ID
date
date and time
decimal hour
light levels in lux
The format is consistent with what is required by the skytrackr() routine.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.