| stk_profile | R Documentation |
Provides static or dynamic (plotly) seasonal profile plot
stk_profile(data, logger, range = c(0, 1e+05), center = "day", plotly = FALSE)
data |
A skytrackr compatible data frame. |
logger |
The logger to plot. |
range |
The light range to plot. |
center |
Set the data to center data on "day" or "night" (default = "day"). |
plotly |
Logical, convert to dynamic plotly plot or not (default = FALSE) |
A static or dynamic graph of light levels for a given logger.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.